# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: featureflags/protobuf/graph.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='featureflags/protobuf/graph.proto',
  package='featureflags.graph',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!featureflags/protobuf/graph.proto\x12\x12\x66\x65\x61tureflags.graph\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"h\n\x03Ref\x12\x11\n\x07Project\x18\x01 \x01(\tH\x00\x12\x0e\n\x04\x46lag\x18\x02 \x01(\tH\x00\x12\x13\n\tCondition\x18\x03 \x01(\tH\x00\x12\x0f\n\x05\x43heck\x18\x04 \x01(\tH\x00\x12\x12\n\x08Variable\x18\x05 \x01(\tH\x00\x42\x04\n\x02to\"\x14\n\x03Set\x12\r\n\x05items\x18\x01 \x03(\t\"\x9e\x01\n\x08Variable\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12/\n\x04type\x18\x03 \x01(\x0e\x32!.featureflags.graph.Variable.Type\"G\n\x04Type\x12\x0f\n\x0b__DEFAULT__\x10\x00\x12\n\n\x06STRING\x10\x01\x12\n\n\x06NUMBER\x10\x02\x12\r\n\tTIMESTAMP\x10\x03\x12\x07\n\x03SET\x10\x04\"\xd3\x03\n\x05\x43heck\x12\n\n\x02id\x18\x01 \x01(\t\x12)\n\x08variable\x18\x02 \x01(\x0b\x32\x17.featureflags.graph.Ref\x12\x34\n\x08operator\x18\x03 \x01(\x0e\x32\".featureflags.graph.Check.Operator\x12\x16\n\x0cvalue_string\x18\x04 \x01(\tH\x00\x12\x16\n\x0cvalue_number\x18\x05 \x01(\x01H\x00\x12\x35\n\x0fvalue_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12,\n\tvalue_set\x18\x07 \x01(\x0b\x32\x17.featureflags.graph.SetH\x00\"\xbf\x01\n\x08Operator\x12\x0f\n\x0b__DEFAULT__\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tLESS_THAN\x10\x02\x12\x11\n\rLESS_OR_EQUAL\x10\x03\x12\x10\n\x0cGREATER_THAN\x10\x04\x12\x14\n\x10GREATER_OR_EQUAL\x10\x05\x12\x0c\n\x08\x43ONTAINS\x10\x06\x12\x0b\n\x07PERCENT\x10\x07\x12\n\n\x06REGEXP\x10\x08\x12\x0c\n\x08WILDCARD\x10\t\x12\n\n\x06SUBSET\x10\n\x12\x0c\n\x08SUPERSET\x10\x0b\x42\x06\n\x04kind\"@\n\tCondition\x12\n\n\x02id\x18\x01 \x01(\t\x12\'\n\x06\x63hecks\x18\x02 \x03(\x0b\x32\x17.featureflags.graph.Ref\"\xd4\x01\n\x04\x46lag\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12(\n\x07project\x18\x03 \x01(\x0b\x32\x17.featureflags.graph.Ref\x12+\n\x07\x65nabled\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12+\n\nconditions\x18\x05 \x03(\x0b\x32\x17.featureflags.graph.Ref\x12.\n\noverridden\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"`\n\x07Project\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\r\x12*\n\tvariables\x18\x03 \x03(\x0b\x32\x17.featureflags.graph.Ref\"\xc6\x01\n\x04Root\x12%\n\x04\x66lag\x18\x01 \x01(\x0b\x32\x17.featureflags.graph.Ref\x12&\n\x05\x66lags\x18\x02 \x03(\x0b\x32\x17.featureflags.graph.Ref\x12)\n\x08projects\x18\x03 \x03(\x0b\x32\x17.featureflags.graph.Ref\x12\x15\n\rauthenticated\x18\x05 \x01(\x08\x12-\n\x0c\x66lags_by_ids\x18\x06 \x03(\x0b\x32\x17.featureflags.graph.Ref\"\xcb\x05\n\x06Result\x12&\n\x04Root\x18\x01 \x01(\x0b\x32\x18.featureflags.graph.Root\x12\x38\n\x07Project\x18\x02 \x03(\x0b\x32\'.featureflags.graph.Result.ProjectEntry\x12\x32\n\x04\x46lag\x18\x03 \x03(\x0b\x32$.featureflags.graph.Result.FlagEntry\x12<\n\tCondition\x18\x04 \x03(\x0b\x32).featureflags.graph.Result.ConditionEntry\x12\x34\n\x05\x43heck\x18\x05 \x03(\x0b\x32%.featureflags.graph.Result.CheckEntry\x12:\n\x08Variable\x18\x06 \x03(\x0b\x32(.featureflags.graph.Result.VariableEntry\x1aK\n\x0cProjectEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.featureflags.graph.Project:\x02\x38\x01\x1a\x45\n\tFlagEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.featureflags.graph.Flag:\x02\x38\x01\x1aO\n\x0e\x43onditionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.featureflags.graph.Condition:\x02\x38\x01\x1aG\n\nCheckEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.featureflags.graph.Check:\x02\x38\x01\x1aM\n\rVariableEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.featureflags.graph.Variable:\x02\x38\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])



_VARIABLE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='featureflags.graph.Variable.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='__DEFAULT__', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NUMBER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIMESTAMP', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SET', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=338,
  serialized_end=409,
)
_sym_db.RegisterEnumDescriptor(_VARIABLE_TYPE)

_CHECK_OPERATOR = _descriptor.EnumDescriptor(
  name='Operator',
  full_name='featureflags.graph.Check.Operator',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='__DEFAULT__', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LESS_OR_EQUAL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREATER_OR_EQUAL', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTAINS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERCENT', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REGEXP', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WILDCARD', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUBSET', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUPERSET', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=680,
  serialized_end=871,
)
_sym_db.RegisterEnumDescriptor(_CHECK_OPERATOR)


_REF = _descriptor.Descriptor(
  name='Ref',
  full_name='featureflags.graph.Ref',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Project', full_name='featureflags.graph.Ref.Project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Flag', full_name='featureflags.graph.Ref.Flag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Condition', full_name='featureflags.graph.Ref.Condition', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Check', full_name='featureflags.graph.Ref.Check', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Variable', full_name='featureflags.graph.Ref.Variable', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='to', full_name='featureflags.graph.Ref.to',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=122,
  serialized_end=226,
)


_SET = _descriptor.Descriptor(
  name='Set',
  full_name='featureflags.graph.Set',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='featureflags.graph.Set.items', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=228,
  serialized_end=248,
)


_VARIABLE = _descriptor.Descriptor(
  name='Variable',
  full_name='featureflags.graph.Variable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='featureflags.graph.Variable.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='featureflags.graph.Variable.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='featureflags.graph.Variable.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VARIABLE_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=409,
)


_CHECK = _descriptor.Descriptor(
  name='Check',
  full_name='featureflags.graph.Check',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='featureflags.graph.Check.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variable', full_name='featureflags.graph.Check.variable', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operator', full_name='featureflags.graph.Check.operator', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_string', full_name='featureflags.graph.Check.value_string', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_number', full_name='featureflags.graph.Check.value_number', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_timestamp', full_name='featureflags.graph.Check.value_timestamp', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_set', full_name='featureflags.graph.Check.value_set', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CHECK_OPERATOR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='featureflags.graph.Check.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=412,
  serialized_end=879,
)


_CONDITION = _descriptor.Descriptor(
  name='Condition',
  full_name='featureflags.graph.Condition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='featureflags.graph.Condition.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checks', full_name='featureflags.graph.Condition.checks', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=881,
  serialized_end=945,
)


_FLAG = _descriptor.Descriptor(
  name='Flag',
  full_name='featureflags.graph.Flag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='featureflags.graph.Flag.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='featureflags.graph.Flag.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='project', full_name='featureflags.graph.Flag.project', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='featureflags.graph.Flag.enabled', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conditions', full_name='featureflags.graph.Flag.conditions', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overridden', full_name='featureflags.graph.Flag.overridden', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=948,
  serialized_end=1160,
)


_PROJECT = _descriptor.Descriptor(
  name='Project',
  full_name='featureflags.graph.Project',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='featureflags.graph.Project.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='featureflags.graph.Project.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='featureflags.graph.Project.version', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variables', full_name='featureflags.graph.Project.variables', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1162,
  serialized_end=1258,
)


_ROOT = _descriptor.Descriptor(
  name='Root',
  full_name='featureflags.graph.Root',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flag', full_name='featureflags.graph.Root.flag', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='featureflags.graph.Root.flags', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='projects', full_name='featureflags.graph.Root.projects', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authenticated', full_name='featureflags.graph.Root.authenticated', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags_by_ids', full_name='featureflags.graph.Root.flags_by_ids', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1261,
  serialized_end=1459,
)


_RESULT_PROJECTENTRY = _descriptor.Descriptor(
  name='ProjectEntry',
  full_name='featureflags.graph.Result.ProjectEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='featureflags.graph.Result.ProjectEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='featureflags.graph.Result.ProjectEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1798,
  serialized_end=1873,
)

_RESULT_FLAGENTRY = _descriptor.Descriptor(
  name='FlagEntry',
  full_name='featureflags.graph.Result.FlagEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='featureflags.graph.Result.FlagEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='featureflags.graph.Result.FlagEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1875,
  serialized_end=1944,
)

_RESULT_CONDITIONENTRY = _descriptor.Descriptor(
  name='ConditionEntry',
  full_name='featureflags.graph.Result.ConditionEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='featureflags.graph.Result.ConditionEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='featureflags.graph.Result.ConditionEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1946,
  serialized_end=2025,
)

_RESULT_CHECKENTRY = _descriptor.Descriptor(
  name='CheckEntry',
  full_name='featureflags.graph.Result.CheckEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='featureflags.graph.Result.CheckEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='featureflags.graph.Result.CheckEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2027,
  serialized_end=2098,
)

_RESULT_VARIABLEENTRY = _descriptor.Descriptor(
  name='VariableEntry',
  full_name='featureflags.graph.Result.VariableEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='featureflags.graph.Result.VariableEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='featureflags.graph.Result.VariableEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2100,
  serialized_end=2177,
)

_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='featureflags.graph.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Root', full_name='featureflags.graph.Result.Root', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Project', full_name='featureflags.graph.Result.Project', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Flag', full_name='featureflags.graph.Result.Flag', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Condition', full_name='featureflags.graph.Result.Condition', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Check', full_name='featureflags.graph.Result.Check', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Variable', full_name='featureflags.graph.Result.Variable', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESULT_PROJECTENTRY, _RESULT_FLAGENTRY, _RESULT_CONDITIONENTRY, _RESULT_CHECKENTRY, _RESULT_VARIABLEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1462,
  serialized_end=2177,
)

_REF.oneofs_by_name['to'].fields.append(
  _REF.fields_by_name['Project'])
_REF.fields_by_name['Project'].containing_oneof = _REF.oneofs_by_name['to']
_REF.oneofs_by_name['to'].fields.append(
  _REF.fields_by_name['Flag'])
_REF.fields_by_name['Flag'].containing_oneof = _REF.oneofs_by_name['to']
_REF.oneofs_by_name['to'].fields.append(
  _REF.fields_by_name['Condition'])
_REF.fields_by_name['Condition'].containing_oneof = _REF.oneofs_by_name['to']
_REF.oneofs_by_name['to'].fields.append(
  _REF.fields_by_name['Check'])
_REF.fields_by_name['Check'].containing_oneof = _REF.oneofs_by_name['to']
_REF.oneofs_by_name['to'].fields.append(
  _REF.fields_by_name['Variable'])
_REF.fields_by_name['Variable'].containing_oneof = _REF.oneofs_by_name['to']
_VARIABLE.fields_by_name['type'].enum_type = _VARIABLE_TYPE
_VARIABLE_TYPE.containing_type = _VARIABLE
_CHECK.fields_by_name['variable'].message_type = _REF
_CHECK.fields_by_name['operator'].enum_type = _CHECK_OPERATOR
_CHECK.fields_by_name['value_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CHECK.fields_by_name['value_set'].message_type = _SET
_CHECK_OPERATOR.containing_type = _CHECK
_CHECK.oneofs_by_name['kind'].fields.append(
  _CHECK.fields_by_name['value_string'])
_CHECK.fields_by_name['value_string'].containing_oneof = _CHECK.oneofs_by_name['kind']
_CHECK.oneofs_by_name['kind'].fields.append(
  _CHECK.fields_by_name['value_number'])
_CHECK.fields_by_name['value_number'].containing_oneof = _CHECK.oneofs_by_name['kind']
_CHECK.oneofs_by_name['kind'].fields.append(
  _CHECK.fields_by_name['value_timestamp'])
_CHECK.fields_by_name['value_timestamp'].containing_oneof = _CHECK.oneofs_by_name['kind']
_CHECK.oneofs_by_name['kind'].fields.append(
  _CHECK.fields_by_name['value_set'])
_CHECK.fields_by_name['value_set'].containing_oneof = _CHECK.oneofs_by_name['kind']
_CONDITION.fields_by_name['checks'].message_type = _REF
_FLAG.fields_by_name['project'].message_type = _REF
_FLAG.fields_by_name['enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_FLAG.fields_by_name['conditions'].message_type = _REF
_FLAG.fields_by_name['overridden'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_PROJECT.fields_by_name['variables'].message_type = _REF
_ROOT.fields_by_name['flag'].message_type = _REF
_ROOT.fields_by_name['flags'].message_type = _REF
_ROOT.fields_by_name['projects'].message_type = _REF
_ROOT.fields_by_name['flags_by_ids'].message_type = _REF
_RESULT_PROJECTENTRY.fields_by_name['value'].message_type = _PROJECT
_RESULT_PROJECTENTRY.containing_type = _RESULT
_RESULT_FLAGENTRY.fields_by_name['value'].message_type = _FLAG
_RESULT_FLAGENTRY.containing_type = _RESULT
_RESULT_CONDITIONENTRY.fields_by_name['value'].message_type = _CONDITION
_RESULT_CONDITIONENTRY.containing_type = _RESULT
_RESULT_CHECKENTRY.fields_by_name['value'].message_type = _CHECK
_RESULT_CHECKENTRY.containing_type = _RESULT
_RESULT_VARIABLEENTRY.fields_by_name['value'].message_type = _VARIABLE
_RESULT_VARIABLEENTRY.containing_type = _RESULT
_RESULT.fields_by_name['Root'].message_type = _ROOT
_RESULT.fields_by_name['Project'].message_type = _RESULT_PROJECTENTRY
_RESULT.fields_by_name['Flag'].message_type = _RESULT_FLAGENTRY
_RESULT.fields_by_name['Condition'].message_type = _RESULT_CONDITIONENTRY
_RESULT.fields_by_name['Check'].message_type = _RESULT_CHECKENTRY
_RESULT.fields_by_name['Variable'].message_type = _RESULT_VARIABLEENTRY
DESCRIPTOR.message_types_by_name['Ref'] = _REF
DESCRIPTOR.message_types_by_name['Set'] = _SET
DESCRIPTOR.message_types_by_name['Variable'] = _VARIABLE
DESCRIPTOR.message_types_by_name['Check'] = _CHECK
DESCRIPTOR.message_types_by_name['Condition'] = _CONDITION
DESCRIPTOR.message_types_by_name['Flag'] = _FLAG
DESCRIPTOR.message_types_by_name['Project'] = _PROJECT
DESCRIPTOR.message_types_by_name['Root'] = _ROOT
DESCRIPTOR.message_types_by_name['Result'] = _RESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Ref = _reflection.GeneratedProtocolMessageType('Ref', (_message.Message,), {
  'DESCRIPTOR' : _REF,
  '__module__' : 'featureflags.protobuf.graph_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.graph.Ref)
  })
_sym_db.RegisterMessage(Ref)

Set = _reflection.GeneratedProtocolMessageType('Set', (_message.Message,), {
  'DESCRIPTOR' : _SET,
  '__module__' : 'featureflags.protobuf.graph_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.graph.Set)
  })
_sym_db.RegisterMessage(Set)

Variable = _reflection.GeneratedProtocolMessageType('Variable', (_message.Message,), {
  'DESCRIPTOR' : _VARIABLE,
  '__module__' : 'featureflags.protobuf.graph_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.graph.Variable)
  })
_sym_db.RegisterMessage(Variable)

Check = _reflection.GeneratedProtocolMessageType('Check', (_message.Message,), {
  'DESCRIPTOR' : _CHECK,
  '__module__' : 'featureflags.protobuf.graph_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.graph.Check)
  })
_sym_db.RegisterMessage(Check)

Condition = _reflection.GeneratedProtocolMessageType('Condition', (_message.Message,), {
  'DESCRIPTOR' : _CONDITION,
  '__module__' : 'featureflags.protobuf.graph_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.graph.Condition)
  })
_sym_db.RegisterMessage(Condition)

Flag = _reflection.GeneratedProtocolMessageType('Flag', (_message.Message,), {
  'DESCRIPTOR' : _FLAG,
  '__module__' : 'featureflags.protobuf.graph_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.graph.Flag)
  })
_sym_db.RegisterMessage(Flag)

Project = _reflection.GeneratedProtocolMessageType('Project', (_message.Message,), {
  'DESCRIPTOR' : _PROJECT,
  '__module__' : 'featureflags.protobuf.graph_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.graph.Project)
  })
_sym_db.RegisterMessage(Project)

Root = _reflection.GeneratedProtocolMessageType('Root', (_message.Message,), {
  'DESCRIPTOR' : _ROOT,
  '__module__' : 'featureflags.protobuf.graph_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.graph.Root)
  })
_sym_db.RegisterMessage(Root)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {

  'ProjectEntry' : _reflection.GeneratedProtocolMessageType('ProjectEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESULT_PROJECTENTRY,
    '__module__' : 'featureflags.protobuf.graph_pb2'
    # @@protoc_insertion_point(class_scope:featureflags.graph.Result.ProjectEntry)
    })
  ,

  'FlagEntry' : _reflection.GeneratedProtocolMessageType('FlagEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESULT_FLAGENTRY,
    '__module__' : 'featureflags.protobuf.graph_pb2'
    # @@protoc_insertion_point(class_scope:featureflags.graph.Result.FlagEntry)
    })
  ,

  'ConditionEntry' : _reflection.GeneratedProtocolMessageType('ConditionEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESULT_CONDITIONENTRY,
    '__module__' : 'featureflags.protobuf.graph_pb2'
    # @@protoc_insertion_point(class_scope:featureflags.graph.Result.ConditionEntry)
    })
  ,

  'CheckEntry' : _reflection.GeneratedProtocolMessageType('CheckEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESULT_CHECKENTRY,
    '__module__' : 'featureflags.protobuf.graph_pb2'
    # @@protoc_insertion_point(class_scope:featureflags.graph.Result.CheckEntry)
    })
  ,

  'VariableEntry' : _reflection.GeneratedProtocolMessageType('VariableEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESULT_VARIABLEENTRY,
    '__module__' : 'featureflags.protobuf.graph_pb2'
    # @@protoc_insertion_point(class_scope:featureflags.graph.Result.VariableEntry)
    })
  ,
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'featureflags.protobuf.graph_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.graph.Result)
  })
_sym_db.RegisterMessage(Result)
_sym_db.RegisterMessage(Result.ProjectEntry)
_sym_db.RegisterMessage(Result.FlagEntry)
_sym_db.RegisterMessage(Result.ConditionEntry)
_sym_db.RegisterMessage(Result.CheckEntry)
_sym_db.RegisterMessage(Result.VariableEntry)


_RESULT_PROJECTENTRY._options = None
_RESULT_FLAGENTRY._options = None
_RESULT_CONDITIONENTRY._options = None
_RESULT_CHECKENTRY._options = None
_RESULT_VARIABLEENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: featureflags/protobuf/backend.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hiku.protobuf import query_pb2 as hiku_dot_protobuf_dot_query__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from featureflags.protobuf import graph_pb2 as featureflags_dot_protobuf_dot_graph__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='featureflags/protobuf/backend.proto',
  package='featureflags.backend',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#featureflags/protobuf/backend.proto\x12\x14\x66\x65\x61tureflags.backend\x1a\x19hiku/protobuf/query.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!featureflags/protobuf/graph.proto\"\x13\n\x02Id\x12\r\n\x05value\x18\x01 \x01(\t\"\'\n\x07LocalId\x12\r\n\x05value\x18\x01 \x01(\t\x12\r\n\x05scope\x18\x02 \x01(\t\"m\n\x08\x45itherId\x12&\n\x02id\x18\x01 \x01(\x0b\x32\x18.featureflags.backend.IdH\x00\x12\x31\n\x08local_id\x18\x02 \x01(\x0b\x32\x1d.featureflags.backend.LocalIdH\x00\x42\x06\n\x04kind\",\n\x06SignIn\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"\t\n\x07SignOut\"7\n\nEnableFlag\x12)\n\x07\x66lag_id\x18\x01 \x01(\x0b\x32\x18.featureflags.backend.Id\"8\n\x0b\x44isableFlag\x12)\n\x07\x66lag_id\x18\x01 \x01(\x0b\x32\x18.featureflags.backend.Id\"6\n\tResetFlag\x12)\n\x07\x66lag_id\x18\x01 \x01(\x0b\x32\x18.featureflags.backend.Id\"\xba\x02\n\x08\x41\x64\x64\x43heck\x12/\n\x08local_id\x18\x01 \x01(\x0b\x32\x1d.featureflags.backend.LocalId\x12*\n\x08variable\x18\x02 \x01(\x0b\x32\x18.featureflags.backend.Id\x12\x34\n\x08operator\x18\x03 \x01(\x0e\x32\".featureflags.graph.Check.Operator\x12\x16\n\x0cvalue_string\x18\x04 \x01(\tH\x00\x12\x16\n\x0cvalue_number\x18\x05 \x01(\x01H\x00\x12\x35\n\x0fvalue_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12,\n\tvalue_set\x18\x07 \x01(\x0b\x32\x17.featureflags.graph.SetH\x00\x42\x06\n\x04kind\"\x9a\x01\n\x0c\x41\x64\x64\x43ondition\x12)\n\x07\x66lag_id\x18\x01 \x01(\x0b\x32\x18.featureflags.backend.Id\x12/\n\x08local_id\x18\x02 \x01(\x0b\x32\x1d.featureflags.backend.LocalId\x12.\n\x06\x63hecks\x18\x03 \x03(\x0b\x32\x1e.featureflags.backend.EitherId\"B\n\x10\x44isableCondition\x12.\n\x0c\x63ondition_id\x18\x01 \x01(\x0b\x32\x18.featureflags.backend.Id\"\xd7\x03\n\tOperation\x12\x37\n\x0b\x65nable_flag\x18\x01 \x01(\x0b\x32 .featureflags.backend.EnableFlagH\x00\x12\x39\n\x0c\x64isable_flag\x18\x02 \x01(\x0b\x32!.featureflags.backend.DisableFlagH\x00\x12;\n\radd_condition\x18\x03 \x01(\x0b\x32\".featureflags.backend.AddConditionH\x00\x12\x43\n\x11\x64isable_condition\x18\x04 \x01(\x0b\x32&.featureflags.backend.DisableConditionH\x00\x12\x33\n\tadd_check\x18\x05 \x01(\x0b\x32\x1e.featureflags.backend.AddCheckH\x00\x12\x35\n\nreset_flag\x18\x06 \x01(\x0b\x32\x1f.featureflags.backend.ResetFlagH\x00\x12/\n\x07sign_in\x18\x07 \x01(\x0b\x32\x1c.featureflags.backend.SignInH\x00\x12\x31\n\x08sign_out\x18\x08 \x01(\x0b\x32\x1d.featureflags.backend.SignOutH\x00\x42\x04\n\x02op\"h\n\x07Request\x12\x33\n\noperations\x18\x01 \x03(\x0b\x32\x1f.featureflags.backend.Operation\x12(\n\x05query\x18\x02 \x01(\x0b\x32\x19.hiku.protobuf.query.Node\"3\n\x05Reply\x12*\n\x06result\x18\x01 \x01(\x0b\x32\x1a.featureflags.graph.Result2\x98\x01\n\x07\x42\x61\x63kend\x12G\n\x04\x63\x61ll\x12\x1d.featureflags.backend.Request\x1a\x1b.featureflags.backend.Reply\"\x03\x88\x02\x01\x12\x44\n\x04\x43\x61ll\x12\x1d.featureflags.backend.Request\x1a\x1b.featureflags.backend.Reply\"\x00\x62\x06proto3'
  ,
  dependencies=[hiku_dot_protobuf_dot_query__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,featureflags_dot_protobuf_dot_graph__pb2.DESCRIPTOR,])




_ID = _descriptor.Descriptor(
  name='Id',
  full_name='featureflags.backend.Id',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='featureflags.backend.Id.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=156,
  serialized_end=175,
)


_LOCALID = _descriptor.Descriptor(
  name='LocalId',
  full_name='featureflags.backend.LocalId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='featureflags.backend.LocalId.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scope', full_name='featureflags.backend.LocalId.scope', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=177,
  serialized_end=216,
)


_EITHERID = _descriptor.Descriptor(
  name='EitherId',
  full_name='featureflags.backend.EitherId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='featureflags.backend.EitherId.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_id', full_name='featureflags.backend.EitherId.local_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='featureflags.backend.EitherId.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=218,
  serialized_end=327,
)


_SIGNIN = _descriptor.Descriptor(
  name='SignIn',
  full_name='featureflags.backend.SignIn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='featureflags.backend.SignIn.username', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='featureflags.backend.SignIn.password', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=329,
  serialized_end=373,
)


_SIGNOUT = _descriptor.Descriptor(
  name='SignOut',
  full_name='featureflags.backend.SignOut',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=375,
  serialized_end=384,
)


_ENABLEFLAG = _descriptor.Descriptor(
  name='EnableFlag',
  full_name='featureflags.backend.EnableFlag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flag_id', full_name='featureflags.backend.EnableFlag.flag_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=386,
  serialized_end=441,
)


_DISABLEFLAG = _descriptor.Descriptor(
  name='DisableFlag',
  full_name='featureflags.backend.DisableFlag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flag_id', full_name='featureflags.backend.DisableFlag.flag_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=443,
  serialized_end=499,
)


_RESETFLAG = _descriptor.Descriptor(
  name='ResetFlag',
  full_name='featureflags.backend.ResetFlag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flag_id', full_name='featureflags.backend.ResetFlag.flag_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=501,
  serialized_end=555,
)


_ADDCHECK = _descriptor.Descriptor(
  name='AddCheck',
  full_name='featureflags.backend.AddCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='local_id', full_name='featureflags.backend.AddCheck.local_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variable', full_name='featureflags.backend.AddCheck.variable', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operator', full_name='featureflags.backend.AddCheck.operator', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_string', full_name='featureflags.backend.AddCheck.value_string', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_number', full_name='featureflags.backend.AddCheck.value_number', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_timestamp', full_name='featureflags.backend.AddCheck.value_timestamp', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_set', full_name='featureflags.backend.AddCheck.value_set', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='featureflags.backend.AddCheck.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=558,
  serialized_end=872,
)


_ADDCONDITION = _descriptor.Descriptor(
  name='AddCondition',
  full_name='featureflags.backend.AddCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flag_id', full_name='featureflags.backend.AddCondition.flag_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_id', full_name='featureflags.backend.AddCondition.local_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checks', full_name='featureflags.backend.AddCondition.checks', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=875,
  serialized_end=1029,
)


_DISABLECONDITION = _descriptor.Descriptor(
  name='DisableCondition',
  full_name='featureflags.backend.DisableCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='condition_id', full_name='featureflags.backend.DisableCondition.condition_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1031,
  serialized_end=1097,
)


_OPERATION = _descriptor.Descriptor(
  name='Operation',
  full_name='featureflags.backend.Operation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable_flag', full_name='featureflags.backend.Operation.enable_flag', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_flag', full_name='featureflags.backend.Operation.disable_flag', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_condition', full_name='featureflags.backend.Operation.add_condition', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_condition', full_name='featureflags.backend.Operation.disable_condition', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_check', full_name='featureflags.backend.Operation.add_check', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reset_flag', full_name='featureflags.backend.Operation.reset_flag', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sign_in', full_name='featureflags.backend.Operation.sign_in', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sign_out', full_name='featureflags.backend.Operation.sign_out', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='op', full_name='featureflags.backend.Operation.op',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1100,
  serialized_end=1571,
)


_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='featureflags.backend.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='featureflags.backend.Request.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='featureflags.backend.Request.query', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1573,
  serialized_end=1677,
)


_REPLY = _descriptor.Descriptor(
  name='Reply',
  full_name='featureflags.backend.Reply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='featureflags.backend.Reply.result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1679,
  serialized_end=1730,
)

_EITHERID.fields_by_name['id'].message_type = _ID
_EITHERID.fields_by_name['local_id'].message_type = _LOCALID
_EITHERID.oneofs_by_name['kind'].fields.append(
  _EITHERID.fields_by_name['id'])
_EITHERID.fields_by_name['id'].containing_oneof = _EITHERID.oneofs_by_name['kind']
_EITHERID.oneofs_by_name['kind'].fields.append(
  _EITHERID.fields_by_name['local_id'])
_EITHERID.fields_by_name['local_id'].containing_oneof = _EITHERID.oneofs_by_name['kind']
_ENABLEFLAG.fields_by_name['flag_id'].message_type = _ID
_DISABLEFLAG.fields_by_name['flag_id'].message_type = _ID
_RESETFLAG.fields_by_name['flag_id'].message_type = _ID
_ADDCHECK.fields_by_name['local_id'].message_type = _LOCALID
_ADDCHECK.fields_by_name['variable'].message_type = _ID
_ADDCHECK.fields_by_name['operator'].enum_type = featureflags_dot_protobuf_dot_graph__pb2._CHECK_OPERATOR
_ADDCHECK.fields_by_name['value_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ADDCHECK.fields_by_name['value_set'].message_type = featureflags_dot_protobuf_dot_graph__pb2._SET
_ADDCHECK.oneofs_by_name['kind'].fields.append(
  _ADDCHECK.fields_by_name['value_string'])
_ADDCHECK.fields_by_name['value_string'].containing_oneof = _ADDCHECK.oneofs_by_name['kind']
_ADDCHECK.oneofs_by_name['kind'].fields.append(
  _ADDCHECK.fields_by_name['value_number'])
_ADDCHECK.fields_by_name['value_number'].containing_oneof = _ADDCHECK.oneofs_by_name['kind']
_ADDCHECK.oneofs_by_name['kind'].fields.append(
  _ADDCHECK.fields_by_name['value_timestamp'])
_ADDCHECK.fields_by_name['value_timestamp'].containing_oneof = _ADDCHECK.oneofs_by_name['kind']
_ADDCHECK.oneofs_by_name['kind'].fields.append(
  _ADDCHECK.fields_by_name['value_set'])
_ADDCHECK.fields_by_name['value_set'].containing_oneof = _ADDCHECK.oneofs_by_name['kind']
_ADDCONDITION.fields_by_name['flag_id'].message_type = _ID
_ADDCONDITION.fields_by_name['local_id'].message_type = _LOCALID
_ADDCONDITION.fields_by_name['checks'].message_type = _EITHERID
_DISABLECONDITION.fields_by_name['condition_id'].message_type = _ID
_OPERATION.fields_by_name['enable_flag'].message_type = _ENABLEFLAG
_OPERATION.fields_by_name['disable_flag'].message_type = _DISABLEFLAG
_OPERATION.fields_by_name['add_condition'].message_type = _ADDCONDITION
_OPERATION.fields_by_name['disable_condition'].message_type = _DISABLECONDITION
_OPERATION.fields_by_name['add_check'].message_type = _ADDCHECK
_OPERATION.fields_by_name['reset_flag'].message_type = _RESETFLAG
_OPERATION.fields_by_name['sign_in'].message_type = _SIGNIN
_OPERATION.fields_by_name['sign_out'].message_type = _SIGNOUT
_OPERATION.oneofs_by_name['op'].fields.append(
  _OPERATION.fields_by_name['enable_flag'])
_OPERATION.fields_by_name['enable_flag'].containing_oneof = _OPERATION.oneofs_by_name['op']
_OPERATION.oneofs_by_name['op'].fields.append(
  _OPERATION.fields_by_name['disable_flag'])
_OPERATION.fields_by_name['disable_flag'].containing_oneof = _OPERATION.oneofs_by_name['op']
_OPERATION.oneofs_by_name['op'].fields.append(
  _OPERATION.fields_by_name['add_condition'])
_OPERATION.fields_by_name['add_condition'].containing_oneof = _OPERATION.oneofs_by_name['op']
_OPERATION.oneofs_by_name['op'].fields.append(
  _OPERATION.fields_by_name['disable_condition'])
_OPERATION.fields_by_name['disable_condition'].containing_oneof = _OPERATION.oneofs_by_name['op']
_OPERATION.oneofs_by_name['op'].fields.append(
  _OPERATION.fields_by_name['add_check'])
_OPERATION.fields_by_name['add_check'].containing_oneof = _OPERATION.oneofs_by_name['op']
_OPERATION.oneofs_by_name['op'].fields.append(
  _OPERATION.fields_by_name['reset_flag'])
_OPERATION.fields_by_name['reset_flag'].containing_oneof = _OPERATION.oneofs_by_name['op']
_OPERATION.oneofs_by_name['op'].fields.append(
  _OPERATION.fields_by_name['sign_in'])
_OPERATION.fields_by_name['sign_in'].containing_oneof = _OPERATION.oneofs_by_name['op']
_OPERATION.oneofs_by_name['op'].fields.append(
  _OPERATION.fields_by_name['sign_out'])
_OPERATION.fields_by_name['sign_out'].containing_oneof = _OPERATION.oneofs_by_name['op']
_REQUEST.fields_by_name['operations'].message_type = _OPERATION
_REQUEST.fields_by_name['query'].message_type = hiku_dot_protobuf_dot_query__pb2._NODE
_REPLY.fields_by_name['result'].message_type = featureflags_dot_protobuf_dot_graph__pb2._RESULT
DESCRIPTOR.message_types_by_name['Id'] = _ID
DESCRIPTOR.message_types_by_name['LocalId'] = _LOCALID
DESCRIPTOR.message_types_by_name['EitherId'] = _EITHERID
DESCRIPTOR.message_types_by_name['SignIn'] = _SIGNIN
DESCRIPTOR.message_types_by_name['SignOut'] = _SIGNOUT
DESCRIPTOR.message_types_by_name['EnableFlag'] = _ENABLEFLAG
DESCRIPTOR.message_types_by_name['DisableFlag'] = _DISABLEFLAG
DESCRIPTOR.message_types_by_name['ResetFlag'] = _RESETFLAG
DESCRIPTOR.message_types_by_name['AddCheck'] = _ADDCHECK
DESCRIPTOR.message_types_by_name['AddCondition'] = _ADDCONDITION
DESCRIPTOR.message_types_by_name['DisableCondition'] = _DISABLECONDITION
DESCRIPTOR.message_types_by_name['Operation'] = _OPERATION
DESCRIPTOR.message_types_by_name['Request'] = _REQUEST
DESCRIPTOR.message_types_by_name['Reply'] = _REPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Id = _reflection.GeneratedProtocolMessageType('Id', (_message.Message,), {
  'DESCRIPTOR' : _ID,
  '__module__' : 'featureflags.protobuf.backend_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.backend.Id)
  })
_sym_db.RegisterMessage(Id)

LocalId = _reflection.GeneratedProtocolMessageType('LocalId', (_message.Message,), {
  'DESCRIPTOR' : _LOCALID,
  '__module__' : 'featureflags.protobuf.backend_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.backend.LocalId)
  })
_sym_db.RegisterMessage(LocalId)

EitherId = _reflection.GeneratedProtocolMessageType('EitherId', (_message.Message,), {
  'DESCRIPTOR' : _EITHERID,
  '__module__' : 'featureflags.protobuf.backend_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.backend.EitherId)
  })
_sym_db.RegisterMessage(EitherId)

SignIn = _reflection.GeneratedProtocolMessageType('SignIn', (_message.Message,), {
  'DESCRIPTOR' : _SIGNIN,
  '__module__' : 'featureflags.protobuf.backend_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.backend.SignIn)
  })
_sym_db.RegisterMessage(SignIn)

SignOut = _reflection.GeneratedProtocolMessageType('SignOut', (_message.Message,), {
  'DESCRIPTOR' : _SIGNOUT,
  '__module__' : 'featureflags.protobuf.backend_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.backend.SignOut)
  })
_sym_db.RegisterMessage(SignOut)

EnableFlag = _reflection.GeneratedProtocolMessageType('EnableFlag', (_message.Message,), {
  'DESCRIPTOR' : _ENABLEFLAG,
  '__module__' : 'featureflags.protobuf.backend_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.backend.EnableFlag)
  })
_sym_db.RegisterMessage(EnableFlag)

DisableFlag = _reflection.GeneratedProtocolMessageType('DisableFlag', (_message.Message,), {
  'DESCRIPTOR' : _DISABLEFLAG,
  '__module__' : 'featureflags.protobuf.backend_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.backend.DisableFlag)
  })
_sym_db.RegisterMessage(DisableFlag)

ResetFlag = _reflection.GeneratedProtocolMessageType('ResetFlag', (_message.Message,), {
  'DESCRIPTOR' : _RESETFLAG,
  '__module__' : 'featureflags.protobuf.backend_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.backend.ResetFlag)
  })
_sym_db.RegisterMessage(ResetFlag)

AddCheck = _reflection.GeneratedProtocolMessageType('AddCheck', (_message.Message,), {
  'DESCRIPTOR' : _ADDCHECK,
  '__module__' : 'featureflags.protobuf.backend_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.backend.AddCheck)
  })
_sym_db.RegisterMessage(AddCheck)

AddCondition = _reflection.GeneratedProtocolMessageType('AddCondition', (_message.Message,), {
  'DESCRIPTOR' : _ADDCONDITION,
  '__module__' : 'featureflags.protobuf.backend_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.backend.AddCondition)
  })
_sym_db.RegisterMessage(AddCondition)

DisableCondition = _reflection.GeneratedProtocolMessageType('DisableCondition', (_message.Message,), {
  'DESCRIPTOR' : _DISABLECONDITION,
  '__module__' : 'featureflags.protobuf.backend_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.backend.DisableCondition)
  })
_sym_db.RegisterMessage(DisableCondition)

Operation = _reflection.GeneratedProtocolMessageType('Operation', (_message.Message,), {
  'DESCRIPTOR' : _OPERATION,
  '__module__' : 'featureflags.protobuf.backend_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.backend.Operation)
  })
_sym_db.RegisterMessage(Operation)

Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
  'DESCRIPTOR' : _REQUEST,
  '__module__' : 'featureflags.protobuf.backend_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.backend.Request)
  })
_sym_db.RegisterMessage(Request)

Reply = _reflection.GeneratedProtocolMessageType('Reply', (_message.Message,), {
  'DESCRIPTOR' : _REPLY,
  '__module__' : 'featureflags.protobuf.backend_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.backend.Reply)
  })
_sym_db.RegisterMessage(Reply)



_BACKEND = _descriptor.ServiceDescriptor(
  name='Backend',
  full_name='featureflags.backend.Backend',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1733,
  serialized_end=1885,
  methods=[
  _descriptor.MethodDescriptor(
    name='call',
    full_name='featureflags.backend.Backend.call',
    index=0,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=b'\210\002\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Call',
    full_name='featureflags.backend.Backend.Call',
    index=1,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_BACKEND)

DESCRIPTOR.services_by_name['Backend'] = _BACKEND

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: featureflags/protobuf/service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hiku.protobuf import query_pb2 as hiku_dot_protobuf_dot_query__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from featureflags.protobuf import graph_pb2 as featureflags_dot_protobuf_dot_graph__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='featureflags/protobuf/service.proto',
  package='featureflags.service',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#featureflags/protobuf/service.proto\x12\x14\x66\x65\x61tureflags.service\x1a\x19hiku/protobuf/query.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!featureflags/protobuf/graph.proto\"I\n\x08Variable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0e\x32!.featureflags.graph.Variable.Type\"w\n\tFlagUsage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x08interval\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0enegative_count\x18\x03 \x01(\r\x12\x16\n\x0epositive_count\x18\x04 \x01(\r\"\xc6\x01\n\x0f\x45xchangeRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r\x12\x31\n\tvariables\x18\x03 \x03(\x0b\x32\x1e.featureflags.service.Variable\x12\x34\n\x0b\x66lags_usage\x18\x04 \x03(\x0b\x32\x1f.featureflags.service.FlagUsage\x12(\n\x05query\x18\x05 \x01(\x0b\x32\x19.hiku.protobuf.query.Node\"L\n\rExchangeReply\x12\x0f\n\x07version\x18\x01 \x01(\r\x12*\n\x06result\x18\x02 \x01(\x0b\x32\x1a.featureflags.graph.Result\"\x7f\n\x0eStoreStatsTask\x12\x0f\n\x07\x66lag_id\x18\x01 \x01(\t\x12,\n\x08interval\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0enegative_count\x18\x03 \x01(\r\x12\x16\n\x0epositive_count\x18\x04 \x01(\r2\xe5\x02\n\x0c\x46\x65\x61tureFlags\x12[\n\x08\x65xchange\x12%.featureflags.service.ExchangeRequest\x1a#.featureflags.service.ExchangeReply\"\x03\x88\x02\x01\x12X\n\x08\x45xchange\x12%.featureflags.service.ExchangeRequest\x1a#.featureflags.service.ExchangeReply\"\x00\x12P\n\x0bstore_stats\x12$.featureflags.service.StoreStatsTask\x1a\x16.google.protobuf.Empty\"\x03\x88\x02\x01\x12L\n\nStoreStats\x12$.featureflags.service.StoreStatsTask\x1a\x16.google.protobuf.Empty\"\x00\x62\x06proto3'
  ,
  dependencies=[hiku_dot_protobuf_dot_query__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,featureflags_dot_protobuf_dot_graph__pb2.DESCRIPTOR,])




_VARIABLE = _descriptor.Descriptor(
  name='Variable',
  full_name='featureflags.service.Variable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='featureflags.service.Variable.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='featureflags.service.Variable.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=185,
  serialized_end=258,
)


_FLAGUSAGE = _descriptor.Descriptor(
  name='FlagUsage',
  full_name='featureflags.service.FlagUsage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='featureflags.service.FlagUsage.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='featureflags.service.FlagUsage.interval', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='negative_count', full_name='featureflags.service.FlagUsage.negative_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='positive_count', full_name='featureflags.service.FlagUsage.positive_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=260,
  serialized_end=379,
)


_EXCHANGEREQUEST = _descriptor.Descriptor(
  name='ExchangeRequest',
  full_name='featureflags.service.ExchangeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='featureflags.service.ExchangeRequest.project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='featureflags.service.ExchangeRequest.version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variables', full_name='featureflags.service.ExchangeRequest.variables', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags_usage', full_name='featureflags.service.ExchangeRequest.flags_usage', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='featureflags.service.ExchangeRequest.query', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=382,
  serialized_end=580,
)


_EXCHANGEREPLY = _descriptor.Descriptor(
  name='ExchangeReply',
  full_name='featureflags.service.ExchangeReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='featureflags.service.ExchangeReply.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='featureflags.service.ExchangeReply.result', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=582,
  serialized_end=658,
)


_STORESTATSTASK = _descriptor.Descriptor(
  name='StoreStatsTask',
  full_name='featureflags.service.StoreStatsTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flag_id', full_name='featureflags.service.StoreStatsTask.flag_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='featureflags.service.StoreStatsTask.interval', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='negative_count', full_name='featureflags.service.StoreStatsTask.negative_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='positive_count', full_name='featureflags.service.StoreStatsTask.positive_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=660,
  serialized_end=787,
)

_VARIABLE.fields_by_name['type'].enum_type = featureflags_dot_protobuf_dot_graph__pb2._VARIABLE_TYPE
_FLAGUSAGE.fields_by_name['interval'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXCHANGEREQUEST.fields_by_name['variables'].message_type = _VARIABLE
_EXCHANGEREQUEST.fields_by_name['flags_usage'].message_type = _FLAGUSAGE
_EXCHANGEREQUEST.fields_by_name['query'].message_type = hiku_dot_protobuf_dot_query__pb2._NODE
_EXCHANGEREPLY.fields_by_name['result'].message_type = featureflags_dot_protobuf_dot_graph__pb2._RESULT
_STORESTATSTASK.fields_by_name['interval'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['Variable'] = _VARIABLE
DESCRIPTOR.message_types_by_name['FlagUsage'] = _FLAGUSAGE
DESCRIPTOR.message_types_by_name['ExchangeRequest'] = _EXCHANGEREQUEST
DESCRIPTOR.message_types_by_name['ExchangeReply'] = _EXCHANGEREPLY
DESCRIPTOR.message_types_by_name['StoreStatsTask'] = _STORESTATSTASK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Variable = _reflection.GeneratedProtocolMessageType('Variable', (_message.Message,), {
  'DESCRIPTOR' : _VARIABLE,
  '__module__' : 'featureflags.protobuf.service_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.service.Variable)
  })
_sym_db.RegisterMessage(Variable)

FlagUsage = _reflection.GeneratedProtocolMessageType('FlagUsage', (_message.Message,), {
  'DESCRIPTOR' : _FLAGUSAGE,
  '__module__' : 'featureflags.protobuf.service_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.service.FlagUsage)
  })
_sym_db.RegisterMessage(FlagUsage)

ExchangeRequest = _reflection.GeneratedProtocolMessageType('ExchangeRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXCHANGEREQUEST,
  '__module__' : 'featureflags.protobuf.service_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.service.ExchangeRequest)
  })
_sym_db.RegisterMessage(ExchangeRequest)

ExchangeReply = _reflection.GeneratedProtocolMessageType('ExchangeReply', (_message.Message,), {
  'DESCRIPTOR' : _EXCHANGEREPLY,
  '__module__' : 'featureflags.protobuf.service_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.service.ExchangeReply)
  })
_sym_db.RegisterMessage(ExchangeReply)

StoreStatsTask = _reflection.GeneratedProtocolMessageType('StoreStatsTask', (_message.Message,), {
  'DESCRIPTOR' : _STORESTATSTASK,
  '__module__' : 'featureflags.protobuf.service_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.service.StoreStatsTask)
  })
_sym_db.RegisterMessage(StoreStatsTask)



_FEATUREFLAGS = _descriptor.ServiceDescriptor(
  name='FeatureFlags',
  full_name='featureflags.service.FeatureFlags',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=790,
  serialized_end=1147,
  methods=[
  _descriptor.MethodDescriptor(
    name='exchange',
    full_name='featureflags.service.FeatureFlags.exchange',
    index=0,
    containing_service=None,
    input_type=_EXCHANGEREQUEST,
    output_type=_EXCHANGEREPLY,
    serialized_options=b'\210\002\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Exchange',
    full_name='featureflags.service.FeatureFlags.Exchange',
    index=1,
    containing_service=None,
    input_type=_EXCHANGEREQUEST,
    output_type=_EXCHANGEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='store_stats',
    full_name='featureflags.service.FeatureFlags.store_stats',
    index=2,
    containing_service=None,
    input_type=_STORESTATSTASK,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StoreStats',
    full_name='featureflags.service.FeatureFlags.StoreStats',
    index=3,
    containing_service=None,
    input_type=_STORESTATSTASK,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FEATUREFLAGS)

DESCRIPTOR.services_by_name['FeatureFlags'] = _FEATUREFLAGS

# @@protoc_insertion_point(module_scope)



from setuptools import setup, find_packages

setup(
    name='evo-featureflags-protobuf',
    version='0.2.1',
    description='Protocol Buffers stub files for feature flags service',
    author='Vladimir Magamedov',
    author_email='vladimir@magamedov.com',
    packages=find_packages(),
    install_requires=[],
)
